@@ -163,8 +163,8 @@ def export_coco_instance(dataset, export_folder):
             'id': image_id,
             # 'license': 1,
             'file_name': sample['file_name'],
-            'height': sample['image'].size[1],
-            'width': sample['image'].size[0],
+            'height': sample['image'].size[1] if sample['image'] is not None else None,
+            'width': sample['image'].size[0] if sample['image'] is not None else None,
     #         'date_captured': "2013-11-14 17:02:52",
     #         'coco_url': "http://images.cocodataset.org/val2017/000000397133.jpg",
     #         'flickr_url': "http://farm7.staticflickr.com/6116/6255196340_da26cf2c9e_z.jpg",        
@@ -284,8 +284,8 @@ def export_coco_panoptic(dataset, export_folder):
         images.append({        
             'id': image_id,
             'file_name': sample['file_name'],
-            'height': sample['image'].size[1],
-            'width': sample['image'].size[0],
+            'height': sample['image'].size[1] if sample['image'] is not None else None,
+            'width': sample['image'].size[0] if sample['image'] is not None else None,
         })
         
         # Annotations
